@@ -14,7 +14,7 @@ use strict;
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Tue Mar  6 20:59:09 Local time zone must be set--see zic manual page 2007
+## Configuration time: Sun Mar  4 10:39:07 Local time zone must be set--see zic manual page 2007
 ## Configured by     : Gentoo
 ## Target system     : linux hake 2.6.19.2 #2 thu feb 1 19:58:15 est 2007 parisc pa8600 (pcx-w+) gnulinux 
 #
@@ -98,10 +98,10 @@ api_subversion='0'
 api_version='8'
 api_versionstring='5.8.0'
 ar='ar'
-archlib='/usr/lib/perl5/5.8.8/hppa1.1-linux'
-archlibexp='/usr/lib/perl5/5.8.8/hppa1.1-linux'
+archlib='/usr/lib/perl5/5.8.8/hppa2.0-linux'
+archlibexp='/usr/lib/perl5/5.8.8/hppa2.0-linux'
 archname64=''
-archname='hppa1.1-linux'
+archname='hppa2.0-linux'
 archobjs=''
 asctime_r_proto='0'
 awk='awk'
@@ -113,9 +113,9 @@ bison='bison'
 byacc='byacc'
 byteorder='4321'
 c=''
-castflags='0'
+castflags='1'
 cat='cat'
-cc='hppa1.1-unknown-linux-gnu-gcc'
+cc='hppa2.0-unknown-linux-gnu-gcc'
 cccdlflags='-fPIC'
 ccdlflags='-rdynamic'
 ccflags='-fno-strict-aliasing -pipe -Wdeclaration-after-statement -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -I/usr/include/gdbm'
@@ -125,7 +125,7 @@ ccsymbols=''
 ccversion=''
 cf_by='Gentoo'
 cf_email='Gentoo@hake.dev.gentoo.org'
-cf_time='Tue Mar  6 20:59:09 Local time zone must be set--see zic manual page 2007'
+cf_time='Sun Mar  4 10:39:07 Local time zone must be set--see zic manual page 2007'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -134,7 +134,7 @@ clocktype='clock_t'
 comm='comm'
 compress=''
 config_arg0='Configure'
-config_arg10='-Doptimize=-O2 -pipe -march=1.1'
+config_arg10='-Doptimize=-O2 -pipe -march=2.0'
 config_arg11='-Duselargefiles'
 config_arg12='-Dd_semctl_semun'
 config_arg13='-Dscriptdir=/usr/bin'
@@ -145,24 +145,24 @@ config_arg17='-Dinstallman3dir=/usr/share/man/man3'
 config_arg18='-Dman1ext=1'
 config_arg19='-Dman3ext=3pm'
 config_arg1='-des'
-config_arg20='-Dinc_version_list=5.8.0 5.8.0/hppa1.1-linux 5.8.2 5.8.2/hppa1.1-linux 5.8.4 5.8.4/hppa1.1-linux 5.8.5 5.8.5/hppa1.1-linux 5.8.6 5.8.6/hppa1.1-linux 5.8.7 5.8.7/hppa1.1-linux '
-config_arg21='-Dinc_version_list=5.8.0 5.8.0/hppa1.1-linux 5.8.2 5.8.2/hppa1.1-linux 5.8.4 5.8.4/hppa1.1-linux 5.8.5 5.8.5/hppa1.1-linux 5.8.6 5.8.6/hppa1.1-linux 5.8.7 5.8.7/hppa1.1-linux '
+config_arg20='-Dinc_version_list=5.8.0 5.8.0/hppa2.0-linux 5.8.2 5.8.2/hppa2.0-linux 5.8.4 5.8.4/hppa2.0-linux 5.8.5 5.8.5/hppa2.0-linux 5.8.6 5.8.6/hppa2.0-linux 5.8.7 5.8.7/hppa2.0-linux '
+config_arg21='-Dinc_version_list=5.8.0 5.8.0/hppa2.0-linux 5.8.2 5.8.2/hppa2.0-linux 5.8.4 5.8.4/hppa2.0-linux 5.8.5 5.8.5/hppa2.0-linux 5.8.6 5.8.6/hppa2.0-linux 5.8.7 5.8.7/hppa2.0-linux '
 config_arg22='-Dcf_by=Gentoo'
 config_arg23='-Ud_csh'
 config_arg24='-Dusenm'
 config_arg25='-Ui_ndbm'
 config_arg26='-Ui_gdbm'
 config_arg27='-Ui_db'
-config_arg2='-Darchname=hppa1.1-linux'
+config_arg2='-Darchname=hppa2.0-linux'
 config_arg3='-Dcccdlflags=-fPIC'
 config_arg4='-Dccdlflags=-rdynamic'
-config_arg5='-Dcc=hppa1.1-unknown-linux-gnu-gcc'
+config_arg5='-Dcc=hppa2.0-unknown-linux-gnu-gcc'
 config_arg6='-Dprefix=/usr'
 config_arg7='-Dvendorprefix=/usr'
 config_arg8='-Dsiteprefix=/usr'
 config_arg9='-Dlocincpth= '
 config_argc='27'
-config_args='-des -Darchname=hppa1.1-linux -Dcccdlflags=-fPIC -Dccdlflags=-rdynamic -Dcc=hppa1.1-unknown-linux-gnu-gcc -Dprefix=/usr -Dvendorprefix=/usr -Dsiteprefix=/usr -Dlocincpth=  -Doptimize=-O2 -pipe -march=1.1 -Duselargefiles -Dd_semctl_semun -Dscriptdir=/usr/bin -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dinstallman1dir=/usr/share/man/man1 -Dinstallman3dir=/usr/share/man/man3 -Dman1ext=1 -Dman3ext=3pm -Dinc_version_list=5.8.0 5.8.0/hppa1.1-linux 5.8.2 5.8.2/hppa1.1-linux 5.8.4 5.8.4/hppa1.1-linux 5.8.5 5.8.5/hppa1.1-linux 5.8.6 5.8.6/hppa1.1-linux 5.8.7 5.8.7/hppa1.1-linux  -Dinc_version_list=5.8.0 5.8.0/hppa1.1-linux 5.8.2 5.8.2/hppa1.1-linux 5.8.4 5.8.4/hppa1.1-linux 5.8.5 5.8.5/hppa1.1-linux 5.8.6 5.8.6/hppa1.1-linux 5.8.7 5.8.7/hppa1.1-linux  -Dcf_by=Gentoo -Ud_csh -Dusenm -Ui_ndbm -Ui_gdbm -Ui_db'
+config_args='-des -Darchname=hppa2.0-linux -Dcccdlflags=-fPIC -Dccdlflags=-rdynamic -Dcc=hppa2.0-unknown-linux-gnu-gcc -Dprefix=/usr -Dvendorprefix=/usr -Dsiteprefix=/usr -Dlocincpth=  -Doptimize=-O2 -pipe -march=2.0 -Duselargefiles -Dd_semctl_semun -Dscriptdir=/usr/bin -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dinstallman1dir=/usr/share/man/man1 -Dinstallman3dir=/usr/share/man/man3 -Dman1ext=1 -Dman3ext=3pm -Dinc_version_list=5.8.0 5.8.0/hppa2.0-linux 5.8.2 5.8.2/hppa2.0-linux 5.8.4 5.8.4/hppa2.0-linux 5.8.5 5.8.5/hppa2.0-linux 5.8.6 5.8.6/hppa2.0-linux 5.8.7 5.8.7/hppa2.0-linux  -Dinc_version_list=5.8.0 5.8.0/hppa2.0-linux 5.8.2 5.8.2/hppa2.0-linux 5.8.4 5.8.4/hppa2.0-linux 5.8.5 5.8.5/hppa2.0-linux 5.8.6 5.8.6/hppa2.0-linux 5.8.7 5.8.7/hppa2.0-linux  -Dcf_by=Gentoo -Ud_csh -Dusenm -Ui_ndbm -Ui_gdbm -Ui_db'
 contains='grep'
 cp='cp'
 cpio=''
@@ -172,9 +172,9 @@ cppccsymbols=''
 cppflags='-fno-strict-aliasing -pipe -Wdeclaration-after-statement -I/usr/include/gdbm'
 cpplast='-'
 cppminus='-'
-cpprun='hppa1.1-unknown-linux-gnu-gcc -E'
-cppstdin='hppa1.1-unknown-linux-gnu-gcc -E'
-cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=3 __GNUC__=4 __GNUC_MINOR__=1 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _PA_RISC1_1=1 _POSIX_C_SOURCE=199506L _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __hppa=1 __hppa__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
+cpprun='hppa2.0-unknown-linux-gnu-gcc -E'
+cppstdin='hppa2.0-unknown-linux-gnu-gcc -E'
+cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=3 __GNUC__=4 __GNUC_MINOR__=1 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _PA_RISC2_0=1 _POSIX_C_SOURCE=199506L _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __hppa=1 __hppa__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
 crypt_r_proto='0'
 cryptlib=''
 csh='csh'
@@ -217,7 +217,7 @@ d_bsdgetpgrp='undef'
 d_bsdsetpgrp='undef'
 d_bzero='define'
 d_casti32='define'
-d_castneg='define'
+d_castneg='undef'
 d_charvspr='define'
 d_chown='define'
 d_chroot='define'
@@ -772,11 +772,11 @@ i_varargs='undef'
 i_varhdr='stdarg.h'
 i_vfork='undef'
 ignore_versioned_solibs='y'
-inc_version_list='5.8.0 5.8.0/hppa1.1-linux 5.8.2 5.8.2/hppa1.1-linux 5.8.4 5.8.4/hppa1.1-linux 5.8.5 5.8.5/hppa1.1-linux 5.8.6 5.8.6/hppa1.1-linux 5.8.7 5.8.7/hppa1.1-linux '
-inc_version_list_init='"5.8.0","5.8.0/hppa1.1-linux","5.8.2","5.8.2/hppa1.1-linux","5.8.4","5.8.4/hppa1.1-linux","5.8.5","5.8.5/hppa1.1-linux","5.8.6","5.8.6/hppa1.1-linux","5.8.7","5.8.7/hppa1.1-linux",0'
+inc_version_list='5.8.0 5.8.0/hppa2.0-linux 5.8.2 5.8.2/hppa2.0-linux 5.8.4 5.8.4/hppa2.0-linux 5.8.5 5.8.5/hppa2.0-linux 5.8.6 5.8.6/hppa2.0-linux 5.8.7 5.8.7/hppa2.0-linux '
+inc_version_list_init='"5.8.0","5.8.0/hppa2.0-linux","5.8.2","5.8.2/hppa2.0-linux","5.8.4","5.8.4/hppa2.0-linux","5.8.5","5.8.5/hppa2.0-linux","5.8.6","5.8.6/hppa2.0-linux","5.8.7","5.8.7/hppa2.0-linux",0'
 incpath=''
 inews=''
-installarchlib='/usr/lib/perl5/5.8.8/hppa1.1-linux'
+installarchlib='/usr/lib/perl5/5.8.8/hppa2.0-linux'
 installbin='/usr/bin'
 installhtml1dir=''
 installhtml3dir=''
@@ -786,7 +786,7 @@ installprefix='/usr'
 installprefixexp='/usr'
 installprivlib='/usr/lib/perl5/5.8.8'
 installscript='/usr/bin'
-installsitearch='/usr/lib/perl5/site_perl/5.8.8/hppa1.1-linux'
+installsitearch='/usr/lib/perl5/site_perl/5.8.8/hppa2.0-linux'
 installsitebin='/usr/bin'
 installsitehtml1dir=''
 installsitehtml3dir=''
@@ -796,7 +796,7 @@ installsiteman3dir='/usr/share/man/man3'
 installsitescript='/usr/bin'
 installstyle='lib/perl5'
 installusrbinperl='undef'
-installvendorarch='/usr/lib/perl5/vendor_perl/5.8.8/hppa1.1-linux'
+installvendorarch='/usr/lib/perl5/vendor_perl/5.8.8/hppa2.0-linux'
 installvendorbin='/usr/bin'
 installvendorhtml1dir=''
 installvendorhtml3dir=''
@@ -811,7 +811,7 @@ ivsize='4'
 ivtype='long'
 known_extensions='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Thread Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
 ksh=''
-ld='hppa1.1-unknown-linux-gnu-gcc'
+ld='hppa2.0-unknown-linux-gnu-gcc'
 lddlflags='-shared -L/usr/local/lib'
 ldflags=' -L/usr/local/lib'
 ldflags_uselargefiles=''
@@ -892,7 +892,7 @@ nvtype='double'
 o_nonblock='O_NONBLOCK'
 obj_ext='.o'
 old_pthread_create_joinable=''
-optimize='-O2 -pipe -march=1.1'
+optimize='-O2 -pipe -march=2.0'
 orderlib='false'
 osname='linux'
 osvers='2.6.19.2'
@@ -978,8 +978,8 @@ sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
 sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 6, 18, 22, 0'
 sig_size='68'
 signal_t='void'
-sitearch='/usr/lib/perl5/site_perl/5.8.8/hppa1.1-linux'
-sitearchexp='/usr/lib/perl5/site_perl/5.8.8/hppa1.1-linux'
+sitearch='/usr/lib/perl5/site_perl/5.8.8/hppa2.0-linux'
+sitearchexp='/usr/lib/perl5/site_perl/5.8.8/hppa2.0-linux'
 sitebin='/usr/bin'
 sitebinexp='/usr/bin'
 sitehtml1dir=''
@@ -1090,8 +1090,8 @@ uvsize='4'
 uvtype='unsigned long'
 uvuformat='"lu"'
 uvxformat='"lx"'
-vendorarch='/usr/lib/perl5/vendor_perl/5.8.8/hppa1.1-linux'
-vendorarchexp='/usr/lib/perl5/vendor_perl/5.8.8/hppa1.1-linux'
+vendorarch='/usr/lib/perl5/vendor_perl/5.8.8/hppa2.0-linux'
+vendorarchexp='/usr/lib/perl5/vendor_perl/5.8.8/hppa2.0-linux'
 vendorbin='/usr/bin'
 vendorbinexp='/usr/bin'
 vendorhtml1dir=' '
